@@ -3,7 +3,7 @@ use clap::Parser;
 use futures::future;
 use futures::executor::block_on;
 use walkdir::WalkDir;
-use std::fs::File;
+use std::fs::{OpenOptions};
 use std::path::{PathBuf};
 use simplelog::{TermLogger, LevelFilter, Config, TerminalMode, ColorChoice, WriteLogger, ConfigBuilder};
 use regex;
@@ -124,6 +124,7 @@ impl Dionysos {
                 .into_iter()
                 .filter_map(|e| e.ok())
                 .filter(|e| e.file_type().is_file()) {
+            log::info!("scanning '{}'", entry.file_name().to_string_lossy());
             while workers.len() >= max_workers {
                 let selector_future = future::select_all(workers);
                 let (result, _, wrkrs) = block_on(selector_future);
@@ -146,7 +147,7 @@ impl Dionysos {
 
         for result in results.iter() {
             if result.has_findings() {
-                println!("{}", result);
+                print!("{}", result);
             }
         }
         
@@ -164,7 +165,7 @@ impl Dionysos {
                     _ => Ok(()),
                 },
             Some(log_file_name) => {
-                let log_file = match File::options().create(true).append(true).open(log_file_name) {
+                let log_file = match OpenOptions::new().create(true).append(true).open(log_file_name) {
                     Ok(file) => file,
                     Err(why) => {
                         eprintln!("unable to write to log file: '{}'", log_file_name);
